@@ -12,6 +12,7 @@ from .stock import *
 def register():
     Pool.register(
         Configuration,
+        ConfigurationProductionSequence,
         BOM,
         BOMInput,
         BOMOutput,
@@ -20,6 +21,7 @@ def register():
         OpenBOMTreeTree,
         Production,
         AssignFailed,
+        Template,
         Product,
         ProductBom,
         ProductionLeadTime,
